==> peekabot-0.6.0.tar.bz2: peekabot-0.6.0/src/client/proxies/SphereProxy.cc <==
/*
 * Copyright Staffan Gimåker 2008-2009.
 *
 * ---
 *
 * Distributed under the Boost Software License, Version 1.0.
 * (See accompanying file LICENSE_1_0.txt or copy at
 * http://www.boost.org/LICENSE_1_0.txt)
 */

#include "SphereProxy.hh"
#include "../PeekabotClient.hh"

#include "../../actions/AddSphere.hh"
#include "../../actions/AssignSphere.hh"


using namespace peekabot;
using namespace peekabot::client;


//
// ------------------ SphereProxyBase implementation -------------------
//


SphereProxyBase::SphereProxyBase()
{
}


SphereProxyBase::SphereProxyBase(const SphereProxyBase &p)
    : ObjectProxyBase(p),
      ScalableProxyBase(p)
{
}


//
// ------------------ SphereProxy implementation -------------------
//


SphereProxy::SphereProxy()
{
}


SphereProxy::SphereProxy(const SphereProxyBase &p)
    : ObjectProxyBase(p),
      SphereProxyBase(p)
{
}


SphereProxy &SphereProxy::operator=(const SphereProxy &p) throw()
{
    return *this = (SphereProxyBase &)p;
}


SphereProxy &SphereProxy::operator=(const SphereProxyBase &p) throw()
{
    unchecked_assign(unchecked_get_client_impl(p), get_pseudonym(p));
    return *this;
}


DelayedDispatch SphereProxy::assign(const ObjectProxyBase &p)
{
    unchecked_assign(get_client_impl(p), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AssignSphere(PathIdentifier(get_object_id(p)), get_object_id()));
}


DelayedDispatch SphereProxy::assign(
    PeekabotClient &client, const std::string &path)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AssignSphere(PathIdentifier(path), get_object_id()));
}


DelayedDispatch SphereProxy::assign(
    const ObjectProxyBase &parent, 
    const std::string &rel_path)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AssignSphere(
            PathIdentifier(get_object_id(parent), rel_path), get_object_id()));
}


DelayedDispatch SphereProxy::add(
    PeekabotClient &client,
    const std::string &path,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddSphere(PathIdentifier(path), conflict_policy, 
                      true, get_object_id()));
}


DelayedDispatch SphereProxy::add(
    const ObjectProxyBase &parent, 
    const std::string &name,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddSphere(PathIdentifier(get_object_id(parent), name), 
                      conflict_policy, true, get_object_id()));
}

==> peekabot-0.8.4.tar.bz2: peekabot-0.8.4/src/client/proxies/SphereProxy.cc <==
/*
 * Copyright Staffan Gimåker 2008-2010.
 *
 * ---
 *
 * Distributed under the Boost Software License, Version 1.0.
 * (See accompanying file LICENSE_1_0.txt or copy at
 * http://www.boost.org/LICENSE_1_0.txt)
 */

#include "SphereProxy.hh"
#include "../PeekabotClient.hh"
#include "../../ObjectTypes.hh"

#include "../../actions/AddObject.hh"
#include "../../actions/Assign.hh"


using namespace peekabot;
using namespace peekabot::client;


//
// ------------------ SphereProxyBase implementation -------------------
//


SphereProxyBase::SphereProxyBase()
{
}


SphereProxyBase::SphereProxyBase(const SphereProxyBase &p)
    : ObjectProxyBase(p),
      ScalableProxyBase(p)
{
}


//
// ------------------ SphereProxy implementation -------------------
//


SphereProxy::SphereProxy()
{
}


SphereProxy::SphereProxy(const SphereProxyBase &p)
    : ObjectProxyBase(p),
      SphereProxyBase(p)
{
}


SphereProxy &SphereProxy::operator=(const SphereProxy &p)
{
    return *this = (SphereProxyBase &)p;
}


SphereProxy &SphereProxy::operator=(const SphereProxyBase &p)
{
    unchecked_assign(unchecked_get_client_impl(p), get_pseudonym(p));
    return *this;
}


DelayedDispatch SphereProxy::assign(const ObjectProxyBase &p)
{
    unchecked_assign(get_client_impl(p), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new Assign(PathIdentifier(get_object_id(p)),
                   get_object_id(), SPHERE_OBJECT));
}


DelayedDispatch SphereProxy::assign(
    PeekabotClient &client, const std::string &path)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new Assign(PathIdentifier(path), get_object_id(), SPHERE_OBJECT));
}


DelayedDispatch SphereProxy::assign(
    const ObjectProxyBase &parent, 
    const std::string &rel_path)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new Assign(
            PathIdentifier(get_object_id(parent), rel_path),
            get_object_id(), SPHERE_OBJECT));
}


DelayedDispatch SphereProxy::add(
    PeekabotClient &client,
    const std::string &path,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(client), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddObject(PathIdentifier(path), conflict_policy,
                      get_object_id(), SPHERE_OBJECT));
}


DelayedDispatch SphereProxy::add(
    const ObjectProxyBase &parent, 
    const std::string &name,
    NameConflictPolicy conflict_policy)
{
    unchecked_assign(get_client_impl(parent), allocate_pseudonym());

    return DelayedDispatch(
        get_client_impl(),
        new AddObject(PathIdentifier(get_object_id(parent), name),
                      conflict_policy, get_object_id(), SPHERE_OBJECT));
}
